Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4032)

Unified Diff: chrome/browser/ui/tabs/tab_strip_model_delegate.h

Issue 74133003: linux-aura: Restore middle-click on new-tab button behaviour. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: tot-merge-nit Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/tabs/tab_strip_model.cc ('k') | chrome/browser/ui/tabs/test_tab_strip_model_delegate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/tabs/tab_strip_model_delegate.h
diff --git a/chrome/browser/ui/tabs/tab_strip_model_delegate.h b/chrome/browser/ui/tabs/tab_strip_model_delegate.h
index cc2f7d2b47fbffd752a0fd5ce718e885dce4d8fd..d3f78f0f60a42acd9d7bcc64d03095f8adc013d7 100644
--- a/chrome/browser/ui/tabs/tab_strip_model_delegate.h
+++ b/chrome/browser/ui/tabs/tab_strip_model_delegate.h
@@ -11,6 +11,7 @@
class Browser;
class DockInfo;
+class GURL;
namespace content {
class WebContents;
@@ -47,9 +48,10 @@ class TabStripModelDelegate {
virtual ~TabStripModelDelegate() {}
- // Adds what the delegate considers to be a blank tab to the model. An |index|
- // value of -1 means to append the contents to the end of the tab strip.
- virtual void AddBlankTabAt(int index, bool foreground) = 0;
+ // Adds a tab to the model and loads |url| in the tab. If |url| is an empty
+ // URL, then the new tab-page is loaded instead. An |index| value of -1
+ // means to append the contents to the end of the tab strip.
+ virtual void AddURLTabAt(const GURL& url, int index, bool foreground) = 0;
// Asks for a new TabStripModel to be created and the given web contentses to
// be added to it. Its size and position are reflected in |window_bounds|.
« no previous file with comments | « chrome/browser/ui/tabs/tab_strip_model.cc ('k') | chrome/browser/ui/tabs/test_tab_strip_model_delegate.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698